pub trait Error:
Error
+ Send
+ Sync {
// Required methods
fn is_timeout(&self) -> bool;
fn err_code(&self) -> Option<u64>;
}Expand description
Trait that represent an error from the transport layer
Required Methods
Sourcefn is_timeout(&self) -> bool
fn is_timeout(&self) -> bool
Check if the current error is a transport timeout